@@ -22,7 +22,6 @@
     Symbol,
     SymbolFor,
     SymbolIterator,
-    SymbolToStringTag,
     TypeError,
   } = window.__bootstrap.primordials;
 
@@ -291,10 +290,6 @@
       webidl.assertBranded(this, URLSearchParams);
       return core.opSync("op_url_stringify_search_params", this[_list]);
     }
-
-    get [SymbolToStringTag]() {
-      return "URLSearchParams";
-    }
   }
 
   webidl.mixinPairIterable("URLSearchParams", URLSearchParams, _list, 0, 1);
@@ -596,10 +591,6 @@
       webidl.assertBranded(this, URL);
       return this[_url].href;
     }
-
-    get [SymbolToStringTag]() {
-      return "URL";
-    }
   }
 
   webidl.configurePrototype(URL);
